package com.zipcodewilmington.froilansfarm;

import com.zipcodewilmington.froilansfarm.Collections.*;
import com.zipcodewilmington.froilansfarm.classes.*;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

import java.util.ArrayList;

public class DailyRoutineTest {

    Farm farm = new Farm();
    FarmHouse home = new FarmHouse();
    Froilan froilan;
    Freelan freelan;
    Tractor tractor;
    Froilanda froilanda;
    CropDuster cropDuster;
    FoodStorage food;


    @Before
    public void setup() {
        freelan = new Freelan();
        froilan = new Froilan();
        tractor = new Tractor();
        froilanda = new Froilanda();
        cropDuster = new CropDuster();
        food = new FoodStorage();
    }


    @Test
    public void sundayTest() {

        Froilan froilan = (Froilan) home.getFroilan();
        Freelan freelan = (Freelan) home.getFreelan();
        froilan.plantCrop(farm.getField(), 0, "tomato");
        froilan.plantCrop(farm.getField(), 1, "corn");
        freelan.plantCrop(farm.getField(), 2, "Broccoli");

        int expected = 180;
        int actual = farm.getField().totalCrops();
        Assert.assertEquals(expected, actual);

    }


    @Test
    public void mondayTest() {
        froilanda.rideTheAircraft();
        ArrayList<CropRow> rows = farm.getField().getCropRows();
        for (CropRow row : rows) {
            for (Crop crop : row.getCroprow()) {
                CropDuster.fertilizeCrop(crop);
            }
        }
    }

    @Test
    public void testTuesday(){
        froilan.rides(tractor);
        ArrayList<CropRow> rows =farm.getField().getCropRows();
        for(CropRow row : rows){
            for(Crop crop : row.getCroprow()){
                tractor.harvestCrop(crop);
            }
        }

        int totalCropRows = farm.getField().totalCroprows();

        freelan.plantCrop(farm.getField(), totalCropRows,"Broccoli");

    }

    @Test
    public void testWednesday() {
        freelan.rides(cropDuster);

        int totalCropRows = farm.getField().getCropRows().size();
        for (int i=0; i<totalCropRows;i++)
            if(i==totalCropRows-1) {
                CropRow row = farm.getField().getCropRows().get(i);
                for (Crop crop : row.getCroprow()) {
                    cropDuster.selectCrop(crop);
                }
            }
    }

    @Test
    public void testCollectEggs(){
        //int noOfCoops = farm.getCoops().length;
        for(ChickenCoop coop : farm.getCoops()){
            coop.eggCollector();
        }
    }

    @Test
    public void testRidingHorse(){
        for(Person person : home.getPersons()){
            for(Stable stable : farm.getStables())
                for(Horse horse : stable.getHorses())
                    person.rideOver(horse);
        }
    }

    @Test
    public void feedingHorse(){
        ArrayList<EarOfCorn> corns = food.getEarOfCorns();
        for(Stable stable : farm.getStables())
            for(Horse horse : stable.getHorses())
                for(EarOfCorn corn : corns)
                    horse.eat(corn);
    }

    @Test
    public void testEverydayEating(){

        for(Person person : home.getPersons()){
            if(person instanceof Froilan)
            {
                froilan.eat(new EarOfCorn());
                froilan.eat(new Tomato());
                froilan.eat(new Tomato());
                for(int i=0;i<5;i++)
                    froilan.eat(new Egg());
            }

            if(person instanceof Froilanda){
                froilanda.eat(new EarOfCorn());
                froilanda.eat(new EarOfCorn());
                froilanda.eat(new Tomato());
                froilan.eat(new Egg());
                froilan.eat(new Egg());
            }

            if(person instanceof Freelan){
                for(int i=0;i<3;i++)
                    freelan.eat(new Tomato());
                froilan.eat(new Egg());
                froilan.eat(new Egg());
            }
        }

    }
}